summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/dialogs/assocpage.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/dialogs/assocpage.h')
-rw-r--r--umbrello/umbrello/dialogs/assocpage.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/umbrello/umbrello/dialogs/assocpage.h b/umbrello/umbrello/dialogs/assocpage.h
index a38aa2ac..469dd35d 100644
--- a/umbrello/umbrello/dialogs/assocpage.h
+++ b/umbrello/umbrello/dialogs/assocpage.h
@@ -40,15 +40,16 @@
*/
class AssocPage : public TQWidget {
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructs an instance of AssocPage.
*
* @param parent The parent of the page
* @param v The view the UMLObject being represented.
* @param o The UMLObject being represented
*/
- AssocPage(TQWidget *parent, UMLView * v, UMLObject * o);
+ AssocPage(TQWidget *tqparent, UMLView * v, UMLObject * o);
/**
* Standard deconstructor.
@@ -40,15 +40,16 @@
* Constructs an instance of AssocPage.
*
- * @param parent The parent of the page
+ * @param tqparent The tqparent of the page
* @param v The view the UMLObject being represented.
* @param o The UMLObject being represented